pub struct DeviceMonitorGetPowerElementDependencyTokenResponse {
pub token: Event,
}Fields
token: EventTrait Implementations
Sourceimpl Decode<DeviceMonitorGetPowerElementDependencyTokenResponse, DefaultFuchsiaResourceDialect> for DeviceMonitorGetPowerElementDependencyTokenResponse
impl Decode<DeviceMonitorGetPowerElementDependencyTokenResponse, DefaultFuchsiaResourceDialect> for DeviceMonitorGetPowerElementDependencyTokenResponse
Sourceimpl Encode<DeviceMonitorGetPowerElementDependencyTokenResponse, DefaultFuchsiaResourceDialect> for &mut DeviceMonitorGetPowerElementDependencyTokenResponse
impl Encode<DeviceMonitorGetPowerElementDependencyTokenResponse, DefaultFuchsiaResourceDialect> for &mut DeviceMonitorGetPowerElementDependencyTokenResponse
Sourceimpl<T0: Encode<HandleType<Event, { _ }, 2147483648>, DefaultFuchsiaResourceDialect>> Encode<DeviceMonitorGetPowerElementDependencyTokenResponse, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<HandleType<Event, { _ }, 2147483648>, DefaultFuchsiaResourceDialect>> Encode<DeviceMonitorGetPowerElementDependencyTokenResponse, DefaultFuchsiaResourceDialect> for (T0,)
impl Eq for DeviceMonitorGetPowerElementDependencyTokenResponse
Sourceimpl Ord for DeviceMonitorGetPowerElementDependencyTokenResponse
impl Ord for DeviceMonitorGetPowerElementDependencyTokenResponse
Sourcefn cmp(
&self,
other: &DeviceMonitorGetPowerElementDependencyTokenResponse,
) -> Ordering
fn cmp( &self, other: &DeviceMonitorGetPowerElementDependencyTokenResponse, ) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialOrd for DeviceMonitorGetPowerElementDependencyTokenResponse
impl PartialOrd for DeviceMonitorGetPowerElementDependencyTokenResponse
Sourcefn partial_cmp(
&self,
other: &DeviceMonitorGetPowerElementDependencyTokenResponse,
) -> Option<Ordering>
fn partial_cmp( &self, other: &DeviceMonitorGetPowerElementDependencyTokenResponse, ) -> Option<Ordering>
Sourceimpl ResourceTypeMarker for DeviceMonitorGetPowerElementDependencyTokenResponse
impl ResourceTypeMarker for DeviceMonitorGetPowerElementDependencyTokenResponse
Sourcetype Borrowed<'a> = &'a mut DeviceMonitorGetPowerElementDependencyTokenResponse
type Borrowed<'a> = &'a mut DeviceMonitorGetPowerElementDependencyTokenResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).impl Standalone<DefaultFuchsiaResourceDialect> for DeviceMonitorGetPowerElementDependencyTokenResponse
impl StructuralPartialEq for DeviceMonitorGetPowerElementDependencyTokenResponse
Sourceimpl TypeMarker for DeviceMonitorGetPowerElementDependencyTokenResponse
impl TypeMarker for DeviceMonitorGetPowerElementDependencyTokenResponse
Sourcetype Owned = DeviceMonitorGetPowerElementDependencyTokenResponse
type Owned = DeviceMonitorGetPowerElementDependencyTokenResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for DeviceMonitorGetPowerElementDependencyTokenResponse
impl RefUnwindSafe for DeviceMonitorGetPowerElementDependencyTokenResponse
impl Send for DeviceMonitorGetPowerElementDependencyTokenResponse
impl Sync for DeviceMonitorGetPowerElementDependencyTokenResponse
impl Unpin for DeviceMonitorGetPowerElementDependencyTokenResponse
impl UnsafeUnpin for DeviceMonitorGetPowerElementDependencyTokenResponse
impl UnwindSafe for DeviceMonitorGetPowerElementDependencyTokenResponse